@@ -27,12 +27,12 @@
 function [zer, gain] = __zero__ (sys, argc)
 
   if (isempty (sys.e))
-    [zer, gain] = slab08nd (sys.a, sys.b, sys.c, sys.d, sys.scaled);
+    [zer, gain] = __sl_ab08nd__ (sys.a, sys.b, sys.c, sys.d, sys.scaled);
   else
-    zer = slag08bd (sys.a, sys.e, sys.b, sys.c, sys.d, sys.scaled);
+    zer = __sl_ag08bd__ (sys.a, sys.e, sys.b, sys.c, sys.d, sys.scaled);
     if (argc > 1 && issiso (sys))
       pol = pole (sys);
-      gain = sltg04bx (sys.a, sys.e, sys.b, sys.c, sys.d, \
+      gain = __sl_tg04bx__ (sys.a, sys.e, sys.b, sys.c, sys.d, \
                        real (pol), imag (pol), real (zer), imag (zer));
     else
       gain = [];
